==> accel-ppp-1.7.4.tar.bz2: accel-ppp-1.7.4/accel-pppd/ctrl/l2tp/attr_defs.h <==
#ifndef __ATTR_DEFS_H
#define __ATTR_DEFS_H

#define Message_Type 0
#define Random_Vector 36
#define Result_Code 1
#define Protocol_Version 2
#define Framing_Capabilities 3
#define Bearer_Capabilities 4
#define Tie_Breaker 5
#define Firmware_Revision 6
#define Host_Name 7
#define Vendor_Name 8
#define Assigned_Tunnel_ID 9
#define Recv_Window_Size 10
#define Challenge 11
#define Challenge_Response 13
#define Cause_Code 12
#define Assigned_Session_ID 14
#define Call_Serial_Number 15
#define Minimum_BPS 16
#define Maximum_BPS 17
#define Bearer_Type 18
#define Framing_Type 19
#define Called_Number 21
#define Calling_Number 22
#define Sub_Address 23
#define TX_Speed 24
#define RX_Speed 38
#define Physical_Channel_ID 25
#define Private_Group_ID 37
#define Sequencing_Required 39
#define Init_Recv_LCP 26
#define Last_Sent_LCP 27
#define Last_Recv_LCP 28
#define Proxy_Authen_Type 29
#define Proxy_Authen_Name 30
#define Proxy_Authen_Challenge 31
#define Proxy_Authen_ID 32
#define Proxy_Authen_Response 33
#define Call_Errors 34
#define ACCM 35
#define Message_Type_Start_Ctrl_Conn_Request 1
#define Message_Type_Start_Ctrl_Conn_Reply 2
#define Message_Type_Start_Ctrl_Conn_Connected 3
#define Message_Type_Stop_Ctrl_Conn_Notify 4
#define Message_Type_Hello 6
#define Message_Type_Outgoing_Call_Request 7
#define Message_Type_Outgoing_Call_Reply 8
#define Message_Type_Outgoing_Call_Connected 9
#define Message_Type_Incoming_Call_Request 10
#define Message_Type_Incoming_Call_Reply 11
#define Message_Type_Incoming_Call_Connected 12
#define Message_Type_Call_Disconnect_Notify 14
#define Message_Type_WAN_Error_Notify 15
#define Message_Type_Set_Link_Info 16
#define Message_Digest 59
#define Router_ID 60
#define Assigned_Connection_ID 61
#define Pseudowire_Capabilities 62
#define Prefered_Language 72
#define Local_Session_ID 63
#define Remote_Session_ID 64
#define Assigned_Cookie 65
#define Remote_End_ID 66
#define Pseudowire_Type 68
#define L2_Specific_Sublayer 69
#define Data_Sequencing 70
#define TX_Connect_Speeed 74
#define RX_Connect_Speeed 75
#define Circuit_Status 71

#endif

==> accel-ppp-1.10.tar.bz2: accel-ppp-1.10/accel-pppd/ctrl/l2tp/attr_defs.h <==
#ifndef __ATTR_DEFS_H
#define __ATTR_DEFS_H

#define Message_Type 0
#define Random_Vector 36
#define Result_Code 1
#define Protocol_Version 2
#define Framing_Capabilities 3
#define Bearer_Capabilities 4
#define Tie_Breaker 5
#define Firmware_Revision 6
#define Host_Name 7
#define Vendor_Name 8
#define Assigned_Tunnel_ID 9
#define Recv_Window_Size 10
#define Challenge 11
#define Challenge_Response 13
#define Cause_Code 12
#define Assigned_Session_ID 14
#define Call_Serial_Number 15
#define Minimum_BPS 16
#define Maximum_BPS 17
#define Bearer_Type 18
#define Framing_Type 19
#define Called_Number 21
#define Calling_Number 22
#define Sub_Address 23
#define TX_Speed 24
#define RX_Speed 38
#define Physical_Channel_ID 25
#define Private_Group_ID 37
#define Sequencing_Required 39
#define Init_Recv_LCP 26
#define Last_Sent_LCP 27
#define Last_Recv_LCP 28
#define Proxy_Authen_Type 29
#define Proxy_Authen_Name 30
#define Proxy_Authen_Challenge 31
#define Proxy_Authen_ID 32
#define Proxy_Authen_Response 33
#define Call_Errors 34
#define ACCM 35
#define Message_Type_Start_Ctrl_Conn_Request 1
#define Message_Type_Start_Ctrl_Conn_Reply 2
#define Message_Type_Start_Ctrl_Conn_Connected 3
#define Message_Type_Stop_Ctrl_Conn_Notify 4
#define Message_Type_Hello 6
#define Message_Type_Outgoing_Call_Request 7
#define Message_Type_Outgoing_Call_Reply 8
#define Message_Type_Outgoing_Call_Connected 9
#define Message_Type_Incoming_Call_Request 10
#define Message_Type_Incoming_Call_Reply 11
#define Message_Type_Incoming_Call_Connected 12
#define Message_Type_Call_Disconnect_Notify 14
#define Message_Type_WAN_Error_Notify 15
#define Message_Type_Set_Link_Info 16
#define Message_Digest 59
#define Ctrl_Message_Auth_Nonce 73
#define Router_ID 60
#define Assigned_Connection_ID 61
#define Pseudowire_Capabilities 62
#define Prefered_Language 72
#define Local_Session_ID 63
#define Remote_Session_ID 64
#define Assigned_Cookie 65
#define Remote_End_ID 66
#define Pseudowire_Type 68
#define L2_Specific_Sublayer 69
#define Data_Sequencing 70
#define TX_Connect_Speed 74
#define RX_Connect_Speed 75
#define Circuit_Status 71
#define Message_Type_Explicit_Ack 20

#endif
